# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['infoblox', 'infoblox.scripts']

package_data = \
{'': ['*']}

install_requires = \
['click-completion>=0.5.2,<0.6.0',
 'click-didyoumean>=0.0.3,<0.0.4',
 'click>=7.0,<8.0',
 'pygments>=2.5.2,<3.0.0',
 'python-dotenv>=0.10.3,<0.11.0',
 'requests>=2.22.0,<3.0.0']

entry_points = \
{'console_scripts': ['ib = infoblox.scripts:cli']}

setup_kwargs = {
    'name': 'ib-client',
    'version': '0.1.4',
    'description': 'Infoblox client',
    'long_description': '# ib-client\n\n[![Pypi version](https://img.shields.io/pypi/v/ib-client.svg)](https://pypi.org/project/ib-client/)\n[![Build Status](https://travis-ci.com/lewoudar/ib_client.svg?branch=master)](https://travis-ci.com/lewoudar/ib_client)\n[![Windows Build Status](https://img.shields.io/appveyor/ci/lewoudar/ib-client/master.svg?label=Windows)](https://ci.appveyor.com/project/lewoudar/ib-client)\n[![Coverage Status](https://codecov.io/gh/lewoudar/ib_client/branch/master/graphs/badge.svg?branch=master&token=J6NUl2epJX)](https://codecov.io/gh/lewoudar/ib_client)\n[![Documentation Status](https://readthedocs.org/projects/ib-client/badge/?version=latest)](https://ib-client.readthedocs.io/en/latest/?badge=latest)\n[![License Apache 2](https://img.shields.io/hexpm/l/plug.svg)](http://www.apache.org/licenses/LICENSE-2.0)\n\nThe simplest infoblox client!\n\n## Why another infoblox client?\n\nThis may be the first question that come to your mind if you know that there is already \na [client](https://infoblox-client.readthedocs.io/en/stable/) supported by Infoblox.\n \nThe answer is **genericity**. I try to be the more generic as possible to support all the objects proposed by the \ninfoblox API through the instropection of its API. If you know the [wapi](https://ipam.illinois.edu/wapidoc)\ndocumentation of an object / function, you will know how to use through the client which has a *simple* and\n*intuitive* API.\n\n## Installation\n\n```bash\npip install ib-client\n```\n\n**N.B: ib-client works starting from python 3.6**\n\n## Documentation\n\nThe documentation is available at https://ib-client.readthedocs.io/en/stable/.\n\n## Features\n\n- A client that allows you to perform all the operations available in the infoblox api.\n- A CLI that allows you to quickly perform the same operations as you will do with the client.\n- Ability to perform custom \n[requests](https://ipam.illinois.edu/wapidoc/additional/samplebodyrequests.html#samplebody-single).\n- Ability to load `.env` files to configure the client or the CLI.\n\n\n## Usage\n\n### Client\n\nHere is how you can instantiate the client.\n\n````python\nfrom infoblox import Client\n\nclient = Client(url=\'https://foo.com/wapi/v2.8\', user=\'foo\', password=\'foo\')\n````\n\nTo create a network:\n\n```python\nnetwork = client.get_object(\'network\')\nnetwork.create(network=\'10.1.0.0/16\')\n```\n\nTo read all networks created:\n\n```python\nnetwork.get()\n```\n\nYou will have an output similar to the following:\n\n```json\n[\n    {\n        "_ref": "network/ZG5zLm5ldHdvcmskMTAuMS4wLjAvMTYvMA:10.1.0.0%2F16",\n        "network": "10.1.0.0/16",\n        "network_view": "default"\n    },\n    {\n        "_ref": "network/ZG5zLm5ldHdvcmskMTAuMi4wLjAvMTYvMA:10.2.0.0%2F16",\n        "network": "10.2.0.0/16",\n        "network_view": "default"\n    }\n]\n```\n\nTo modify a network:\n\n```python\nnetwork.update(object_ref=\'network/ZG5zLm5ldHdvcmskMTAuMS4wLjAvMTYvMA:10.1.0.0/16\', comment=\'just a comment\')\n```\n\nIf you want to search for the network modified, you can do this:\n\n```python\nnetwork.get(params={\'comment~\': \'just\'}, return_fields=[\'network\', \'networkview\', \'comment\'])\n```\n\nIt is also interesting to notice in the last call how we filtered the fields to be returned. The output contains the\nnetwork modified previously.\n\n```json\n[\n    {\n        "_ref": "network/ZG5zLm5ldHdvcmskMTAuMS4wLjAvMTYvMA:10.1.0.0%2F16",\n        "comment": "just a comment",\n        "network": "10.1.0.0/16",\n        "network_view": "default"\n    }\n]\n```\n\n**N.B:** the reference is always returned, so this is why we don\'t need to mention it in the `return_fields` parameter.\n\nFinally to delete a network, you can perform this call:\n\n```python\nnetwork.delete(object_ref=\'network/ZG5zLm5ldHdvcmskMTAuMS4wLjAvMTYvMA:10.1.0.0/16\')\n```\n\nSimple enough!\n\n### CLI\n\nBefore using the CLI, you will have to set 3 environment variables, otherwise you will have an error. The 3 environment\nvariables are:\n- **IB_URL:** the wapi infoblox url like https://foo/wapi/v2.8\n- **IB_USER:** the user to connect to\n- **IB_PASSWORD:** the user\'s password\n\nIf you don\'t want to repeat these actions, you can create a **.env** file in the directory where you want to use the CLI.\nYou need to provide the above information in the form `KEY=VALUE`, one per line.\n\nThe cli has *help information* available to help you quickly understand how to use it\n\n```bash\nib -h\nUsage: ib [OPTIONS] COMMAND [ARGS]...\n\n  Infoblox Command Line Interface. It allows you to interact with infoblox\n  in the same way you will do with the python api client.\n\nOptions:\n  --version   Show the version and exit.\n  -h, --help  Show this message and exit.\n\nCommands:\n  object            Performs various object operations.\n  objects           Lists the available objects supports by the infoblox...\n  request           Makes a custom request using the request object of...\n  schema            Shows the api schema.\n  shell-completion  Installs shell completion.\n```\n\nEach command also has help information available through the `-h` option.\nYou can activate the shell completion on **bash**, **fish**, **zsh** and **Powershell** by doing the following command:\n\n```bash\nib shell-completion\n```\n\n**Note:** On Powershell, you may encounter an error in non administrator mode and if you are in administrator mode,\nand you still encounter an error like the following:\n\n```bash\nSet-ExecutionPolicy : Windows PowerShell updated your execution policy successfully, but the setting is overridden\nby a policy defined at a more specific scope.  Due to the override, your shell will retain its current effective\nexecution policy of Bypass. Type "Get-ExecutionPolicy -List" to view your execution policy settings.\nFor more information please see "Get-Help Set-ExecutionPolicy".\n```\n\nPlease refer to [microsoft documentation](http://go.microsoft.com/fwlink/?LinkId=821719) to know how to fix the issue.\n\nWe will now perform the same operations realized in the client part.\n\nCreate a network:\n\n```bash\nib object -n network create -a \'{"network": "10.1.0.0/16"}\'\n```\n\nNotes: \n- the `-n` option after `object` command specifies the object to work on.\n- On Powershell, you will need a different syntax to escape properly json arguments:\n\n```bash\nib object -n network create -a "{\\"network\\": \\"10.1.0.0/16\\"}"\n```\n\nI know it is ugly and tricky, but we can\'t do differently on Windows :(\n\nTo get all created networks:\n\n```bash\nib object -n network get\n```\n\nUpdate a network:\n\n```bash\nib object -n network update -o network/ZG5zLm5ldHdvcmskMTAuMS4wLjAvMTYvMA:10.1.0.0%2F16 -a \'{"comment":"just a comment"}\'\n```\n\nSearch for a network:\n\n```bash\nib object -n network get -p \'{"comment~":"just"}\' --return-fields=network,networkview,comment\n```\n\nDelete a network:\n\n```bash\nib object -n network delete -o network/ZG5zLm5ldHdvcmskMTAuMS4wLjAvMTYvMA:10.1.0.0%2F16\n```\n\n# Warnings\n\n- The client was created by working on major version 2 of the infoblox API, so it is sure to work on it, will not work\n on a previous major version and is not sure to work on a higher major version.\n- I don\'t have much time to test my client on an infoblox server, so it\'s likely there are some bugs. Feel free to suggest\npull requests. See the CONTRIBUTING.md file for more details. All contributions are welcome :)',
    'author': 'lewoudar',
    'author_email': 'lewoudar@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://ib-client.readthedocs.io/en/stable',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
